# Generated by Django 4.0.3 on 2022-03-13 11:41

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('esi', '0010_set_new_tokens_to_sso_v2'),
        ('eveuniverse', '0005_type_materials_and_sections'),
        ('marketmanager', '0008_alter_order_state'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Config',
            new_name='PublicConfig',
        ),
        migrations.AddField(
            model_name='order',
            name='source_character',
            field=models.BooleanField(default=False, verbose_name='Sourced From Character API Market Data'),
        ),
        migrations.AddField(
            model_name='order',
            name='source_corporation',
            field=models.BooleanField(default=False, verbose_name='Sourced From Corporation API Market Data'),
        ),
        migrations.AddField(
            model_name='order',
            name='source_public',
            field=models.BooleanField(default=False, verbose_name='Sourced From Public Market Data'),
        ),
        migrations.AlterField(
            model_name='structure',
            name='owner_id',
            field=models.IntegerField(verbose_name='Owner Corporation ID'),
        ),
        migrations.CreateModel(
            name='PrivateConfig',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('failed', models.BooleanField(verbose_name='')),
                ('failure_reason', models.CharField(max_length=50, verbose_name='')),
                ('token', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='esi.token', verbose_name='ESI Token')),
                ('valid_corporations', models.ManyToManyField(to='eveonline.evecorporationinfo', verbose_name='Valid Corporation Markets for this Token')),
                ('valid_structures', models.ManyToManyField(to='marketmanager.structure', verbose_name='Valid Structure Markets for this Token')),
            ],
            options={
                'default_permissions': (),
            },
        ),
    ]



# Generated by Django 4.0.3 on 2022-03-18 10:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0018_remove_typestatistics_buy_5_percent_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='order',
            name='escrow',
        ),
        migrations.RemoveField(
            model_name='order',
            name='source_character',
        ),
        migrations.RemoveField(
            model_name='order',
            name='source_corporation',
        ),
        migrations.RemoveField(
            model_name='order',
            name='source_private',
        ),
        migrations.RemoveField(
            model_name='order',
            name='source_public',
        ),
        migrations.RemoveField(
            model_name='order',
            name='volume_total',
        ),
    ]



import os

from allianceauth.services.hooks import get_extension_logger
from esi.clients import EsiClientProvider
from esi.models import Token

logger = get_extension_logger(__name__)

SWAGGER_SPEC = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'swagger.json')
esi = EsiClientProvider(spec_file=SWAGGER_SPEC)

def get_universe_structures(filter: str = "all"):
    result = esi.client.Universe.get_universe_structures(
        filter=filter
    ).results()
    return result


def get_universe_structures_structure_id(structure_id: int, token: Token):
    result = esi.client.Universe.get_universe_structures_structure_id(
        structure_id=structure_id,
        token=token.valid_access_token()
    ).results()
    return result


def get_markets_region_id_orders(region_id: int,
                                 order_type: str = "all"):
    result = esi.client.Market.get_markets_region_id_orders(
        order_type=order_type,
        region_id=region_id
    ).results()
    return result


def get_markets_region_id_orders_paged(
        region_id: int,
        page: int,
        order_type: str = "all"):
    result = esi.client.Market.get_markets_region_id_orders(
        order_type=order_type,
        region_id=region_id,
        page=page
    )
    result.request_config.also_return_response = True
    return result.result()


def get_markets_region_id_orders_by_typeid(region_id: int,
                                           order_type: str = "all",
                                           type_id: str = ""):
    result = esi.client.Market.get_markets_region_id_orders(
        order_type=order_type,
        region_id=region_id,
        type_id=type_id
    ).results()
    return result


def get_markets_region_id_history(region_id: int,
                                  order_type: str = "all",
                                  type_id: str = ""):
    result = esi.client.Market.get_markets_region_id_history(
        order_type=order_type,
        region_id=region_id,
        type_id=type_id
    ).results()
    return result

def get_markets_structures_structure_id(structure_id: int, token: Token):
    result = esi.client.Market.get_markets_structures_structure_id(
        structure_id=structure_id,
        token=token.valid_access_token()
    ).results()
    return result

def get_characters_character_id_orders(character_id: int):
    required_scopes = ['esi-markets.read_character_orders.v1']
    token = Token.get_token(character_id, required_scopes)

    result = esi.client.Market.get_characters_character_id_orders(
        character_id=character_id,
        token=token.valid_access_token()
    ).results()
    return result


def get_characters_character_id_orders_history(character_id: int):
    required_scopes = ['esi-markets.read_character_orders.v1']
    token = Token.get_token(character_id, required_scopes)

    result = esi.client.Market.get_characters_character_id_orders_history(
        character_id=character_id,
        token=token.valid_access_token()
    ).results()
    return result


def get_characters_character_id_roles_from_token(token: Token):
    # Yes this is weird, its because im pulling _specific_ scopes to find this token elsewhere
    result = esi.client.Character.get_characters_character_id_roles(
        character_id=token.character_id,
        token=token.valid_access_token()
        ).results()
    return result


def get_corporations_corporation_id_orders(corporation_id: int, token: Token):
    result = esi.client.Market.get_corporations_corporation_id_orders(
        corporation_id=corporation_id,
        token=token.valid_access_token()
    ).results()
    return result


def get_corporations_corporation_id_orders_history(corporation_id: int, token: Token):
    result = esi.client.Market.get_corporations_corporation_id_orders_history(
        character_id=corporation_id,
        token=token.valid_access_token()
    ).results()
    return result


def get_corporations_corporation_id_structures(corporation_id: int, token: Token):
    result = esi.client.Corporation.get_corporations_corporation_id_structures(
        corporation_id=corporation_id,
        token=token.valid_access_token()
        ).results()
    return result



# Generated by Django 4.0.2 on 2022-02-28 03:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0007_alter_order_is_buy_order'),
    ]

    operations = [
        migrations.AlterField(
            model_name='order',
            name='state',
            field=models.CharField(choices=[('', ''), ('cancelled', 'Cancelled'), ('expired ', 'Expired')], help_text='Current order state, Only valid for Authenticated order History. Will not update from Public Market Data.', max_length=20, verbose_name='Order State'),
        ),
    ]



# Generated by Django 3.2.8 on 2021-11-29 13:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='config',
            options={'default_permissions': ()},
        ),
        migrations.AlterModelOptions(
            name='order',
            options={'default_permissions': ()},
        ),
        migrations.AlterModelOptions(
            name='structure',
            options={'default_permissions': ()},
        ),
        migrations.AlterModelOptions(
            name='watchconfig',
            options={'default_permissions': ()},
        ),
        migrations.AlterModelOptions(
            name='webhook',
            options={'default_permissions': ()},
        ),
    ]



import json

from eveuniverse.tools.testdata import load_testdata_from_dict

from . import test_data_filename


def _load_eveuniverse_from_file():
    with open(test_data_filename(), encoding="utf-8") as f:
        data = json.load(f)

    return data


eveuniverse_testdata = _load_eveuniverse_from_file()


def load_eveuniverse():
    load_testdata_from_dict(eveuniverse_testdata)



# Generated by Django 4.0.3 on 2022-03-19 06:49

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0005_type_materials_and_sections'),
        ('marketmanager', '0022_remove_typestatistics_evetypeeveregiontypestatistic'),
    ]

    operations = [
        migrations.AlterField(
            model_name='typestatistics',
            name='eve_region',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.everegion', verbose_name=''),
        ),
    ]



# Generated by Django 4.0.3 on 2022-03-19 06:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0023_alter_typestatistics_eve_region'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='typestatistics',
            name='new_eden',
        ),
    ]



# Generated by Django 4.0.3 on 2022-03-13 13:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0010_order_source_private'),
    ]

    operations = [
        migrations.AlterField(
            model_name='privateconfig',
            name='failed',
            field=models.BooleanField(verbose_name='Disabled due to Failure, Check reason, adjust config and re-enable'),
        ),
        migrations.AlterField(
            model_name='privateconfig',
            name='failure_reason',
            field=models.CharField(max_length=100, verbose_name='Failure Reason'),
        ),
    ]



from eveuniverse.models import EveRegion, EveType

from django.contrib import admin

from allianceauth.services.hooks import get_extension_logger
from esi.models import Token

from marketmanager.models import (
    Order, PrivateConfig, PublicConfig, StatisticsConfig, Structure,
    WatchConfig, Webhook,
)

logger = get_extension_logger(__name__)


@admin.register(PublicConfig)
class PublicConfigAdmin(admin.ModelAdmin):
    filter_horizontal = ["fetch_regions"]
    def formfield_for_manytomany(self, db_field, request, **kwargs):
        # This should filter Citadels (1657) and NPC Stations (15) as viable Structure_Types for this selection
        if db_field.name == "fetch_regions":
            kwargs["queryset"] = EveRegion.objects.filter(id__lt="11000000")
        return super().formfield_for_manytomany(db_field, request, **kwargs)


@admin.register(StatisticsConfig)
class StatisticsConfig(admin.ModelAdmin):
    filter_horizontal = ["calculate_regions"]

    def formfield_for_manytomany(self, db_field, request, **kwargs):
        if db_field.name == "calculate_regions":
            kwargs["queryset"] = EveRegion.objects.filter(id__lt="11000000")
        return super().formfield_for_manytomany(db_field, request, **kwargs)

@admin.register(PrivateConfig)
class PrivateConfigAdmin(admin.ModelAdmin):
    list_display = ('token', 'failed', 'failure_reason')
    filter_horizontal = ["valid_corporations", "valid_structures"]
    def formfield_for_foreignkey(self, db_field, request, **kwargs):
        if db_field.name == "token":
            required_scopes = ['esi-markets.structure_markets.v1']
            kwargs["queryset"] = Token.objects.all().require_scopes(
            required_scopes
            )
        return super().formfield_for_foreignkey(db_field, request, **kwargs)


@admin.register(WatchConfig)
class WatchConfigAdmin(admin.ModelAdmin):
    list_display = ('eve_type', 'buy_order', 'volume', 'price', )
    filter_horizontal = ["structure","structure_type", "webhooks", "debug_webhooks", "solar_system", "region"]
    autocomplete_fields = ['eve_type']

    def formfield_for_foreignkey(self, db_field, request, **kwargs):
        # Only items that have market groups?
        if db_field.name == "eve_type":
            kwargs["queryset"] = EveType.objects.filter(eve_market_group__isnull=False)
        return super().formfield_for_foreignkey(db_field, request, **kwargs)

    def formfield_for_manytomany(self, db_field, request, **kwargs):
        # This should filter Citadels (1657) and NPC Stations (15) as viable Structure_Types for this selection
        if db_field.name == "structure_type":
            kwargs["queryset"] = EveType.objects.filter(eve_group__id__in=[15, 1657])
        if db_field.name == "region":
            kwargs["queryset"] = EveRegion.objects.filter(id__lt="11000000")
        return super().formfield_for_manytomany(db_field, request, **kwargs)

@admin.register(Order)
class OrderAdmin(admin.ModelAdmin):
    list_display = ('eve_type', 'price', 'eve_solar_system', 'is_buy_order', 'issued_by_character', 'issued_by_corporation', 'updated_at')


@admin.register(Structure)
class StructureAdmin(admin.ModelAdmin):
    list_display = ('name', 'solar_system', 'eve_type', 'owner_id', 'pull_market', 'updated_at')


@admin.register(Webhook)
class WebhookAdmin(admin.ModelAdmin):
    list_display = ('name', )



# Generated by Django 4.0.3 on 2022-03-13 14:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0013_alter_privateconfig_failure_reason_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='privateconfig',
            name='valid_corporations',
            field=models.ManyToManyField(blank=True, to='eveonline.evecorporationinfo', verbose_name='Valid Corporation Markets for this Token'),
        ),
        migrations.AlterField(
            model_name='privateconfig',
            name='valid_structures',
            field=models.ManyToManyField(blank=True, to='marketmanager.structure', verbose_name='Valid Structure Markets for this Token'),
        ),
    ]



# Generated by Django 3.2.8 on 2021-11-30 14:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0004_alter_order_wallet_division'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='general',
            options={'default_permissions': (), 'managed': False, 'permissions': (('basic_market_browser', 'Can access the Market Browser with standard features'), ('order_highlight_user', "Market orders owned by the user's characters may be highlighted in the standard/basic Market Browser"), ('order_highlight_corporation', 'Market orders owned by any corporation a user is a member of may be highlighted in the standard/basic Market Browser WARNING: This has no checks for Corporation Roles.'), ('advanced_market_browser', 'Can access the Market Browser with more detail such as the owners of orders'))},
        ),
    ]



# Generated by Django 4.0.3 on 2022-03-15 14:23

from decimal import Decimal

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('esi', '0010_set_new_tokens_to_sso_v2'),
        ('marketmanager', '0013_watchconfig_managed_app_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='watchconfig',
            name='price',
            field=models.DecimalField(decimal_places=2, default=Decimal('0'), help_text='Set to Zero to skip this filter', max_digits=20, verbose_name='Price'),
        ),
        migrations.CreateModel(
            name='TypeStatistics',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('buy_5_percent', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('sell_5_percent', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('buy_weighted_average', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('sell_weighted_average', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('buy_median', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('sell_median', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('eve_type', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='esi.token', verbose_name='ESI Token')),
            ],
            options={
                'default_permissions': (),
            },
        ),
    ]



# Generated by Django 3.2.8 on 2021-11-26 04:56

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('eveuniverse', '0005_type_materials_and_sections'),
        ('eveonline', '0015_factions'),
    ]

    operations = [
        migrations.CreateModel(
            name='General',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'permissions': (('basic_access', 'Can access this app'),),
                'managed': False,
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Structure',
            fields=[
                ('structure_id', models.PositiveBigIntegerField(primary_key=True, serialize=False, verbose_name='Structure ID')),
                ('name', models.CharField(max_length=100, verbose_name='Name')),
                ('owner_id', models.IntegerField(verbose_name='Owner ID')),
                ('pull_market', models.BooleanField(default=True, help_text='Useful to ignore specific structures for _reasons_', verbose_name='Pull Market Orders')),
                ('eve_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evetype', verbose_name='')),
                ('solar_system', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evesolarsystem', verbose_name='Solar System')),
            ],
        ),
        migrations.CreateModel(
            name='Webhook',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='Name')),
                ('webhook', models.URLField(verbose_name='URL')),
            ],
        ),
        migrations.CreateModel(
            name='WatchConfig',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('buy_order', models.BooleanField(verbose_name='Buy Order')),
                ('volume', models.IntegerField(help_text='Set to Zero to check ANY/EVERY order against Price', verbose_name='Volume')),
                ('price', models.IntegerField(help_text='Set to Zero to check ANY/EVERY order against Volume', verbose_name='Price')),
                ('jita_compare_percent', models.IntegerField(help_text='If set ignores Flat price value', verbose_name='Jita Comparison %')),
                ('constellation', models.ManyToManyField(to='eveuniverse.EveConstellation', verbose_name='')),
                ('location', models.ManyToManyField(to='marketmanager.Structure', verbose_name='')),
                ('region', models.ManyToManyField(to='eveuniverse.EveRegion', verbose_name='')),
                ('solar_system', models.ManyToManyField(to='eveuniverse.EveSolarSystem', verbose_name='')),
                ('structure_type', models.ManyToManyField(help_text='Filter by structure Type/Size/Docking (ie, forts/keeps for cap fuel)', related_name='structure_type', to='eveuniverse.EveType', verbose_name='Structure Type Filter')),
                ('type', models.ManyToManyField(to='eveuniverse.EveType', verbose_name='EVE Types')),
                ('webhooks', models.ManyToManyField(to='marketmanager.Webhook', verbose_name='Webhooks')),
            ],
        ),
        migrations.CreateModel(
            name='Order',
            fields=[
                ('order_id', models.PositiveBigIntegerField(help_text='Unique order ID', primary_key=True, serialize=False, verbose_name='Order ID')),
                ('duration', models.PositiveIntegerField(help_text='Number of days the order was valid for (starting from the issued date). An order expires at time issued + duration', verbose_name='Duration')),
                ('is_buy_order', models.BooleanField(default=False, help_text='True if the order is a bid (buy) order', verbose_name='Buy Order')),
                ('issued', models.DateTimeField(help_text='Date and time when this order was issued', verbose_name='Issued')),
                ('location_id', models.PositiveBigIntegerField(help_text='ID of the location where order was placed', verbose_name='Location ID')),
                ('min_volume', models.PositiveIntegerField(blank=True, help_text='For buy orders, the minimum quantity that will be accepted in a matching sell order', null=True, verbose_name='Minimum Volume')),
                ('price', models.DecimalField(decimal_places=2, help_text='Cost per unit for this order', max_digits=20, verbose_name='Price')),
                ('escrow', models.DecimalField(blank=True, decimal_places=2, help_text='For buy orders, the amount of ISK in escrow', max_digits=20, null=True, verbose_name='Escrow')),
                ('range', models.CharField(choices=[('1', '1'), ('10', '10'), ('2', '2'), ('20', '20'), ('3', '3'), ('30', '30'), ('4', '4'), ('40', '40'), ('5', '5'), ('region', 'Region'), ('solarsystem', 'Solar System'), ('station', 'Station')], help_text='Valid order range, numbers are ranges in jumps', max_length=20, verbose_name='Order Range')),
                ('volume_remain', models.PositiveIntegerField(help_text='Quantity of items still required or offered', verbose_name='Volume Remaining')),
                ('volume_total', models.PositiveIntegerField(help_text='Quantity of items required or offered at time order was placed', verbose_name='Volume Total')),
                ('is_corporation', models.BooleanField(default=False, help_text='Signifies whether the buy/sell order was placed on behalf of a corporation.', verbose_name='Is Corporation')),
                ('wallet_division', models.PositiveIntegerField(blank=True, help_text='The corporation wallet division used for this order.', null=True, verbose_name='Wallet Division')),
                ('state', models.CharField(choices=[('1', '1'), ('10', '10'), ('2', '2'), ('20', '20'), ('3', '3'), ('30', '30'), ('4', '4'), ('40', '40'), ('5', '5'), ('region', 'Region'), ('solarsystem', 'Solar System'), ('station', 'Station')], help_text='Current order state, Only valid for Authenticated order History. Will not update from Public Market Data.', max_length=20, verbose_name='Order State')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('eve_region', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.everegion', verbose_name='Region')),
                ('eve_solar_system', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evesolarsystem', verbose_name='System')),
                ('eve_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evetype', verbose_name='Type')),
                ('issued_by_character', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='eveonline.evecharacter', verbose_name='Character')),
                ('issued_by_corporation', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='eveonline.evecorporationinfo', verbose_name='Corporation')),
            ],
        ),
        migrations.CreateModel(
            name='Config',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('fetch_regions', models.ManyToManyField(to='eveuniverse.EveRegion', verbose_name='Fetch Regions')),
            ],
        ),
    ]



from django.utils.translation import gettext_lazy as _

from allianceauth import hooks
from allianceauth.services.hooks import MenuItemHook, UrlHook

from . import urls


class MarketManagerMarketBrowserMenuItem(MenuItemHook):
    """This class ensures only authorized users will see the menu entry"""

    def __init__(self):
        # setup menu entry for sidebar
        MenuItemHook.__init__(
            self,
            _("Market Browser"),
            "fas fa-store-alt fa-fw",
            "marketmanager:marketbrowser",
            navactive=["marketmanager:marketbrowser"],
        )

    def render(self, request):
        if request.user.has_perm("marketmanager.basic_market_browser"):
            return MenuItemHook.render(self, request)
        return ""


class MarketManagerMarketManagerMenuItem(MenuItemHook):
    """This class ensures only authorized users will see the menu entry"""

    def __init__(self):
        # setup menu entry for sidebar
        MenuItemHook.__init__(
            self,
            _("Market Manager"),
            "fas fa-store-alt-slash fa-fw",
            "marketmanager:marketmanager",
            navactive=["marketmanager:marketmanager"],
        )

    def render(self, request):
        if request.user.has_perm("marketmanager.advanced_market_browser"):
            return MenuItemHook.render(self, request)
        return ""


@hooks.register("menu_item_hook")
def register_menu():
    return MarketManagerMarketBrowserMenuItem()


# @hooks.register("menu_item_hook")
# def register_menu():
#     return MarketManagerMarketManagerMenuItem()


@hooks.register("url_hook")
def register_urls():
    return UrlHook(urls, "marketmanager", r"^marketmanager/")



# Generated by Django 3.2.8 on 2021-12-01 13:43

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0005_type_materials_and_sections'),
        ('marketmanager', '0005_alter_general_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='structure',
            name='eve_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evetype', verbose_name='Type'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='constellation',
            field=models.ManyToManyField(to='eveuniverse.EveConstellation', verbose_name='Constellation'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='location',
            field=models.ManyToManyField(to='marketmanager.Structure', verbose_name='Structure'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='region',
            field=models.ManyToManyField(to='eveuniverse.EveRegion', verbose_name='Region'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='solar_system',
            field=models.ManyToManyField(to='eveuniverse.EveSolarSystem', verbose_name='Solar System'),
        ),
    ]
